@@ -3,10 +3,14 @@
 // Can't use insert since it would shadow set's insert() member
 ostream &FollowSet::oInsert(ostream &out) const
 {
-    out << "{ " << OM::std;
+    out << "{ ";
+
+    Terminal::inserter(&Terminal::plainName);
 
     copy(begin(), end(), ostream_iterator<Element const *>(out, " "));
 
+    Terminal::inserter(&Terminal::valueQuotedName);
+
     if (d_EOF)
         out << "<EOF> ";
 
