@@ -4,7 +4,7 @@ bool Grammar::isDerivable(Production const *prod, Grammar &object)
 {
     return 
         find_if(prod->begin(), prod->end(), 
-            Wrap1c<Symbol, Grammar, bool>(notRemovable, object)
+            FnWrap1c<Symbol const *, Grammar &, bool>(notRemovable, object)
         ) == prod->end();
 }
 
