@@ -4,7 +4,7 @@
 
 // To check for SR conflict, pass each reducible item index together with the
 // context consisting of the state's d_itemVector vector and d_nextVector
-// vector to // Next's checkShiftReduceConflict member which will solve all
+// vector to Next's checkShiftReduceConflict member which will solve all
 // observed shift-reduce conflicts.
 
 void State::checkConflicts() 
@@ -26,4 +26,7 @@ void State::checkConflicts()
     d_rrConflict.inspect();               // detect RR conflicts
 
     d_rrConflict.removeConflicts(d_itemVector);
+
+    if (d_reducible.size() > 1)             // more than 1 reduction
+        setType(REQ_TOKEN);
 }
