@@ -1,12 +1,12 @@
 #include "writer.ih"
 
-void Writer::reduction(ostream &out, StateItem const &stateItem)
+void Writer::reduction(Table &table, StateItem const &stateItem)
 {
-    ReductionContext context = {stateItem.nr(), out};
+    ReductionContext context = {stateItem.nr(), table};
 
     for_each(
         stateItem.lookaheadSet().begin(), stateItem.lookaheadSet().end(),
-        Wrap1c<Element, ReductionContext>(reduction, context));
+        FnWrap1c<Element const *, ReductionContext &>(reduction, context));
 
     if (stateItem.lookaheadSet().hasEOF())
         reduction(Rules::eofTerminal(), context);
